// 
// Copyright (C) 2005 - George Baklarz, Paul Zikopoulos, Dan Scott
// Apache Derby - Off to the Races
//
// The program calls the getPerformance stored procedure to get the productions
// that are playing between two dates.
//

import java.lang.*;
import java.sql.*; 
import java.io.*;

public class CallPerformanceSP {
  
  public static void registerSP(Connection conn) throws SQLException {

	  String dropSP = "DROP PROCEDURE getPerformances";
		String createSP = 
			"CREATE PROCEDURE getPerformances ( " +
			"IN STARTDATE DATE, " +
			"IN ENDDATE   DATE) " +
			"DYNAMIC RESULT SETS 1 " +
			"PARAMETER STYLE JAVA " + 
			"READS SQL DATA " +
			"LANGUAGE JAVA EXTERNAL NAME 'PerformanceSP.getPerformances'" ;
		 
    Statement s = conn.createStatement();
  
    try {
      s.execute(dropSP);      
    } 
    catch (SQLException se) {
    }
    s.execute(createSP);
    s.close();			 
	}
	
  public static void main(String argv[]) throws SQLException {

    Connection conn = null;
    Statement s = null;
    ResultSet rs = null;
    String DerbyDriver = "org.apache.derby.jdbc.EmbeddedDriver";
    String title;
    String startDate;
    String endDate;
    int rows;
      
    try {
       Class.forName(DerbyDriver).newInstance();
    }
    catch (Exception NoDriver) {
       System.out.println("Derby driver not found: " + DerbyDriver);
       NoDriver.printStackTrace();
       System.exit(1);
    }

    try {
      conn = DriverManager.getConnection("jdbc:derby:YMLD");
			registerSP(conn);
      CallableStatement cstmt = conn.prepareCall("call getPerformances(?,?)");
      cstmt.setDate(1,Date.valueOf("2005-03-31"));
      cstmt.setDate(2,Date.valueOf("2005-05-15"));
      cstmt.execute();
      rs = cstmt.getResultSet();
      rows = 0;
      while (rs.next()) {
        if (rows == 0) {
          System.out.println("Start Date End Date   Title" ); 
          System.out.println("---------------------------------------------------");
        }
        ++rows;
        title = rs.getString("Production_Title");
        startDate = rs.getString("Production_Start");
        endDate = rs.getString("Production_End");
        System.out.println(startDate + " " + endDate + " " + title);
      }
      cstmt.close();
      rs.close();
      conn.close();
    }
    catch (SQLException se) {
      String SQLState = se.getSQLState(); 
      String SQLMessage = se.getMessage();
      System.out.println("Error = "+SQLState);
      System.out.println(SQLMessage);
    }
  }
}