// 
// Copyright (C) 2005 - George Baklarz, Paul Zikopoulos, Dan Scott
// Apache Derby - Off to the Races
//
// Moving the cursor in an answer set
//
import java.lang.*;
import java.sql.*; 
import java.io.*;

public class PositionCursor {

  public static void whereAmI(ResultSet rs) throws SQLException {
      System.out.println("isBeforeFirst=" + rs.isBeforeFirst() + " " + 
                         "isFirst=" + rs.isFirst() + " " + 
                         "isLast=" + rs.isLast() + " " +
                         "isAfterLast=" + rs.isAfterLast());
  }   
    

  public static void main(String argv[]) throws SQLException {

    Connection conn = null;
    Statement s = null;
    ResultSet rs = null;
    String DerbyDriver = "org.apache.derby.jdbc.EmbeddedDriver";
    String title;
      
    try {
       Class.forName(DerbyDriver).newInstance();
    }
    catch (Exception NoDriver) {
       System.out.println("Derby driver not found: " + DerbyDriver);
       NoDriver.printStackTrace();
       System.exit(1);
    }

    try {
      conn = DriverManager.getConnection("jdbc:derby:YMLD"); 
      s = conn.createStatement(ResultSet.TYPE_SCROLL_INSENSITIVE,ResultSet.CONCUR_READ_ONLY); 
      rs = s.executeQuery( "SELECT Production_Title FROM Productions");

      try { // View record without positioning with next()
        System.out.println("Trying to access a record before a next()");
        title = rs.getString("PRODUCTION_TITLE");     
      } 
      catch (SQLException se) {
        System.out.println("Error:  "+ se.getMessage());  
      }
      
      rs.next(); // Next record successful
      whereAmI(rs);
      title = rs.getString("PRODUCTION_TITLE");     
      System.out.println("next():   " + title); 
      title = rs.getString("PRODUCTION_TITLE");           
      rs.last(); // Last record successfull
      title = rs.getString("PRODUCTION_TITLE");     
      System.out.println("last():   " + title); 

      rs.next(); // Skip past end
   
      rs.first();
      title = rs.getString("PRODUCTION_TITLE");     
      System.out.println("first():  " + title); 

      rs.relative(3);
      title = rs.getString("PRODUCTION_TITLE");     
      System.out.println("+3 recs:  " + title); 

      rs.relative(-3);
      title = rs.getString("PRODUCTION_TITLE");     
      System.out.println("-3 recs:  " + title); 

      
      System.out.println("Trying to go beyond the end of the record set");
      try {
        rs.relative(10);
        title = rs.getString("PRODUCTION_TITLE");     
      }
      catch (SQLException se) {
        System.out.println("Too far  :  "+ se.getMessage());  
      }     

      rs.close(); 
      s.close();
    }
    catch (SQLException se) {
      String SQLState = se.getSQLState(); 
      String SQLMessage = se.getMessage();
      System.out.println("Error = "+SQLState);
      System.out.println(SQLMessage);
    }
  }
}